/* Plone fixes */

.flexslider{
    margin-bottom:5px;
    a, a:hover, a:link{
        border:none !important;
        color: #444 !important;
        &.linkimg{
            margin: 0px 10px 0px 10px;
            display: block;
            float: left;
        }
    }
    ul,ol{
        margin: 0em !important;
        list-style-type: none !important;
        position: static !important;
    }
    ul.slides{
        img{
           padding-left:0px;
           display:inline;
        }
        li{
            margin-bottom:15px !important;
        }
    }
    .flex-caption{
        float:left;
        width: 80%;
        p{
           margin-bottom: 1em;
        }
    }
    ol.flex-control-nav.flex-control-paging li{
        display:inline-table !important;
    }
    .flex-direction-nav li a{
        padding-top:10px !important;
        border:none !important;
        color: rgba(0,0,0,0.8) !important;
    }
    .flex-direction-nav li a :before{
         line-height:1em !important;
    }
}

#content .flexslider a:hover,
#content .flexslider a:link{
    //color: rgba(0,0,0,0.8) !important;
    color: #000 !important;
}
#content a.flex-next,
#content a.flex-prev{
         height:30px !important;
    }


@media screen and (max-width: 860px) {
  .flex-direction-nav .flex-prev {display:none}
  .flex-direction-nav .flex-next {display:none}
}


.portletSliderCollection{
    div.portletHeader{
        padding: 0.42em 1em;
        background: #ddd;
        line-height: normal;
        font-weight: bold;
        font-size:80%;
    }
}

