/* CPSkin fixes */
.slides-count {
  display: none;
}

/* Plone fixes */
.flexslider {
  margin-bottom: 5px;
}
.flexslider a,
.flexslider a:hover,
.flexslider a:link {
  border: none !important;
  color: #444 !important;
}
.flexslider a.linkimg,
.flexslider a:hover.linkimg,
.flexslider a:link.linkimg {
  margin: 0px 10px 0px 10px;
  display: block;
  float: left;
}
.flexslider ul,
.flexslider ol {
  margin: 0em !important;
  list-style-type: none !important;
  position: static !important;
}
.flexslider ul.slides img {
  padding-left: 0px;
  display: inline;
}
.flexslider ul.slides li {
  margin-bottom: 15px !important;
}
.flexslider .flex-caption {
  float: left;
  width: 80%;
}
.flexslider .flex-caption p {
  margin-bottom: 1em;
}
.flexslider ol.flex-control-nav.flex-control-paging li {
  display: inline-table !important;
}
.flexslider .flex-direction-nav li a {
  padding-top: 10px !important;
  border: none !important;
  color: rgba(0, 0, 0, 0.8) !important;
}
.flexslider .flex-direction-nav li a :before {
  line-height: 1em !important;
}
#content .flexslider a:hover,
#content .flexslider a:link {
  color: #000 !important;
}
#content a.flex-next,
#content a.flex-prev {
  height: 30px !important;
}
/*slider whitout image*/
.slider-without-images [id="carousel-a-la-une"],
.slider-without-images #slider-a-la-une .slides .linkimg{
  display: none !important;
}
.slider-without-images .flex-viewport {
  background: #576574;
}
.slider-without-images .flexslider .flex-caption,
.slider-without-images #slider-a-la-une.flexslider .flex-caption {
  background: #8395a7 !important;
  margin-top: 0px !important;
  height: 200px !important;
  opacity: 1 !important;
  padding: 4% !important;
  width: 90% !important;
  box-sizing: border-box;
  margin: 0 0 0 5%;
}
.slider-without-images {
    max-width: 75%;
}
.slider-without-images .flex-direction-nav .flex-prev {
  left: 1%;
}
.slider-without-images .flex-direction-nav .flex-next{
  right: 1% ;
}
.slider-without-images .flex-direction-nav a{
  opacity: 1;
}
.slider-without-images .read-next-link,
.slider-without-images #slider-a-la-une .read-next-link{
  display: block ;
  background: #8395a7;
  padding: 2% 4%;
  clear: left;
  max-width: 90%;
  margin: 0 auto;
  box-sizing: border-box;
}
.slider-without-images .read-next-link a {
    display: inline-block;
    background: #222f3e;
    width: 17%;
    padding: 2%;
    box-sizing: border-box;
}
/*slider count in carousel*/
.slider-count #carousel-a-la-une .flex-direction-nav {
    display: none;
}
#accueil #flex.slider-count #carousel-a-la-une ul li {
    background-color: transparent !important;
    margin: 0;
    width: 34px !important;
}
.slider-count #carousel-a-la-une .linkimg .flexsliderimg {
    display: none !important;
}
.slider-count .flex-container {
    position: relative;
}
.slider-count #carousel-a-la-une {
    background-color: transparent !important;
    bottom: 0;
    left: 0;
    margin-bottom: 0;
    margin-top: 0em;
    position: relative;
    width: 100%;
}

.slider-count #carousel-a-la-une .flex-caption a {
    visibility: hidden;
}
.slider-count #carousel-a-la-une .flex-caption a::before {
    color: #333;
    content: "\0025CB";
    font-size: 250%;
    visibility: visible;
}
.slider-count #carousel-a-la-une .flex-active-slide .flex-caption a::before {
    color: #333;
    content: "\0025C9";
}

.slider-count #carousel-a-la-une .slides {
    left: 33% !important;
    position: relative !important;
    transform: inherit !important;
    transition-duration: 0s !important;
    width: 100% !important;
}

.slider-count #carousel-a-la-une .flex-viewport {
    top: 0;
}
/*slider vertical*/
.vertical-slider{
  position: relative;
}
.sp-thumbnail-text {
    height: auto;
    width: 60%;
    float: right;
    padding: 2%;
    box-sizing: border-box;
}
.sp-thumbnail-image-container {
    height: auto;
    width: 40%;
    overflow: hidden;
    float: left;
}
.sp-thumbnail{
  background: #f0f0f0;
}
.vertical-slider .sp-right-thumbnails.sp-has-pointer .sp-selected-thumbnail::before {
    border-left-color: #808e9b;
}
.vertical-slider .sp-right-thumbnails.sp-has-pointer .sp-selected-thumbnail::after {
    border-right-color: #808e9b;
}
.vertical-slider .sp-bottom-thumbnails.sp-has-pointer .sp-selected-thumbnail::before,
.vertical-slider .sp-bottom-thumbnails.sp-has-pointer .sp-selected-thumbnail::after{
  border-bottom-color: #808e9b;
}
#content .sp-caption-container a{
  color: #000;
}
.vertical-slider img{
  max-width: 100%;
}

.sp-caption-inner{
  height: 6em;
  overflow: hidden;
}
.sp-thumbnail-title {
    margin-bottom: 5px;
    text-transform: uppercase;
    color: #333;
    font-size: 0.75em;
    line-height: 1.5em;
}
.sp-thumbnail-description {
    font-size: 14px;
    color: #333;
}
.slider-vertical .sp-right-thumbnails .sp-thumbnail-container{
  margin-top: 6px;
}
.portletSliderCollection div.portletHeader {
  padding: 0.42em 1em;
  background: #ddd;
  line-height: normal;
  font-weight: bold;
  font-size: 80%;
}

@media screen and (max-width: 860px) {
  .flex-direction-nav .flex-prev {
    opacity: 1;
    left: 0;
  }
  .flex-direction-nav .flex-next {
    opacity: 1;
    right: 0;
  }
  /*slider count*/
  .slider-count .carousel{
    display: none;
  }
  .slider-count #slider-a-la-une.flexslider .flex-caption{
    height: auto;
    margin-top: 0em;
    opacity: 0.7;
    padding: 0.25em 4% 0.75em;
    width: 92%;
  }
  .slider-count .flex-direction-nav a::before{
    font-size: 25px;
  }
  .slider-count .flex-direction-nav a{
    top: 25%;
  }
  /*slider whitout image*/
  .slider-without-images{
    max-width: 100%;
  }
  .slider-without-images #slider-a-la-une.flexslider .flex-caption{
    height: 250px !important;
    margin: 0 0 0 10%;
    width: 80% !important;
  }
  .slider-without-images #slider-a-la-une .read-next-link{
    max-width: 80%;
  }
  .slider-without-images .read-next-link a{
    padding: 5%;
    width: 100%;
  }
  .slider-without-images .flex-direction-nav a::before{
    font-size: 25px;
  }
  /*slider vertical*/
  .sp-caption-container{
    height: 14em;
  }
  .sp-thumbnails-container{
    display: none;
  }
}

